# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
"""
Const

specifies the shape of a mouse pointer.

See Also:
    `API SystemPointer <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1SystemPointer.html>`_
"""
ARROW: Literal[0]
"""
specifies the normal arrow-like mouse pointer.
"""
INVISIBLE: Literal[1]
"""
specifies an invisible mouse pointer.
"""
WAIT: Literal[2]
"""
specifies a waiting symbol as a mouse pointer (for example hourglass).
"""
TEXT: Literal[3]
"""
specifies a mouse pointer for text (cursor-like).
"""
HELP: Literal[4]
"""
specifies a mouse pointer for on-line help.
"""
CROSS: Literal[5]
"""
specifies a cross as a mouse pointer.
"""
MOVE: Literal[6]
"""
specifies a mouse pointer which symbolizes movement.
"""
NSIZE: Literal[7]
"""
specifies a mouse pointer which symbolizes resizing for a top border.
"""
SSIZE: Literal[8]
"""
specifies a mouse pointer which symbolizes resizing for a bottom border.
"""
WSIZE: Literal[9]
"""
specifies a mouse pointer which symbolizes resizing for a left border.
"""
ESIZE: Literal[10]
"""
specifies a mouse pointer which symbolizes resizing for a right border.
"""
NWSIZE: Literal[11]
"""
specifies a mouse pointer which symbolizes resizing for the top-left corner.
"""
NESIZE: Literal[12]
"""
specifies a mouse pointer which symbolizes resizing for the top-right corner.
"""
SWSIZE: Literal[13]
"""
specifies a mouse pointer which symbolizes resizing for the bottom-left corner.
"""
SESIZE: Literal[14]
"""
specifies a mouse pointer which symbolizes resizing for the bottom-right corner.
"""
WINDOW_NSIZE: Literal[15]
"""
specifies a mouse pointer which symbolizes window resizing for a top border.
"""
WINDOW_SSIZE: Literal[16]
"""
specifies a mouse pointer which symbolizes window resizing for a bottom border.
"""
WINDOW_WSIZE: Literal[17]
"""
specifies a mouse pointer which symbolizes window resizing for a left border.
"""
WINDOW_ESIZE: Literal[18]
"""
specifies a mouse pointer which symbolizes window resizing for a right border.
"""
WINDOW_NWSIZE: Literal[19]
"""
specifies a mouse pointer which symbolizes window resizing for the top-left corner.
"""
WINDOW_NESIZE: Literal[20]
"""
specifies a mouse pointer which symbolizes window resizing for the top-right corner.
"""
WINDOW_SWSIZE: Literal[21]
"""
specifies a mouse pointer which symbolizes window resizing for the bottom-left corner.
"""
WINDOW_SESIZE: Literal[22]
"""
specifies a mouse pointer which symbolizes window resizing for the bottom-right corner.
"""
HSPLIT: Literal[23]
"""
specifies a mouse pointer which symbolizes horizontal splitting.
"""
VSPLIT: Literal[24]
"""
specifies a mouse pointer which symbolizes vertical splitting.
"""
HSIZEBAR: Literal[25]
"""
specifies a mouse pointer which symbolizes horizontal resizing.
"""
VSIZEBAR: Literal[26]
"""
specifies a mouse pointer which symbolizes vertical resizing.
"""
HAND: Literal[27]
"""
specifies a hand symbol as mouse pointer.
"""
REFHAND: Literal[28]
"""
specifies a pointing hand symbol as mouse pointer.
"""
PEN: Literal[29]
"""
specifies a pen symbol as mouse pointer.
"""
MAGNIFY: Literal[30]
"""
specifies a magnify symbol as mouse pointer.
"""
FILL: Literal[31]
"""
specifies a fill symbol as mouse pointer.
"""
ROTATE: Literal[32]
"""
specifies a rotate symbol as mouse pointer.
"""
HSHEAR: Literal[33]
"""
specifies a horizontal shear symbol as mouse pointer.
"""
VSHEAR: Literal[34]
"""
specifies a vertical shear symbol as mouse pointer.
"""
MIRROR: Literal[35]
"""
specifies a mirror symbol as mouse pointer.
"""
CROOK: Literal[36]
"""
specifies a crook symbol as mouse pointer.
"""
CROP: Literal[37]
"""
specifies a crop symbol as mouse pointer.
"""
MOVEPOINT: Literal[38]
"""
specifies a mouse pointer which symbolizes moving a point.
"""
MOVEBEZIERWEIGHT: Literal[39]
"""
specifies a mouse pointer which symbolizes moving a Bezier weight.
"""
MOVEDATA: Literal[40]
"""
specifies a mouse pointer which symbolizes moving data.
"""
COPYDATA: Literal[41]
"""
specifies a mouse pointer which symbolizes copying data.
"""
LINKDATA: Literal[42]
"""
specifies a mouse pointer which symbolizes linking data.
"""
MOVEDATALINK: Literal[43]
"""
specifies a mouse pointer which symbolizes moving a data link.
"""
COPYDATALINK: Literal[44]
"""
specifies a mouse pointer which symbolizes copying a data link.
"""
MOVEFILE: Literal[45]
"""
specifies a mouse pointer which symbolizes moving a file.
"""
COPYFILE: Literal[46]
"""
specifies a mouse pointer which symbolizes copying a file.
"""
LINKFILE: Literal[47]
"""
specifies a mouse pointer which symbolizes linking a file.
"""
MOVEFILELINK: Literal[48]
"""
specifies a mouse pointer which symbolizes moving a file link.
"""
COPYFILELINK: Literal[49]
"""
specifies a mouse pointer which symbolizes copying a file link.
"""
MOVEFILES: Literal[50]
"""
specifies a mouse pointer which symbolizes moving multiple files.
"""
COPYFILES: Literal[51]
"""
specifies a mouse pointer which symbolizes copying multiple files.
"""
NOTALLOWED: Literal[52]
"""
specifies a mouse pointer which symbolizes \"not allowed\".
"""
DRAW_LINE: Literal[53]
"""
specifies a mouse pointer which symbolizes drawing a line.
"""
DRAW_RECT: Literal[54]
"""
specifies a mouse pointer which symbolizes drawing a rectangle.
"""
DRAW_POLYGON: Literal[55]
"""
specifies a mouse pointer which symbolizes drawing a polygon.
"""
DRAW_BEZIER: Literal[56]
"""
specifies a mouse pointer which symbolizes drawing a Bezier.
"""
DRAW_ARC: Literal[57]
"""
specifies a mouse pointer which symbolizes drawing an arc.
"""
DRAW_PIE: Literal[58]
"""
specifies a mouse pointer which symbolizes drawing a pie.
"""
DRAW_CIRCLECUT: Literal[59]
"""
specifies a mouse pointer which symbolizes drawing a circle cut.
"""
DRAW_ELLIPSE: Literal[60]
"""
specifies a mouse pointer which symbolizes drawing an ellipse.
"""
DRAW_FREEHAND: Literal[61]
"""
specifies a mouse pointer which symbolizes drawing free handed.
"""
DRAW_CONNECT: Literal[62]
"""
specifies a mouse pointer which symbolizes drawing a connector.
"""
DRAW_TEXT: Literal[63]
"""
specifies a mouse pointer which symbolizes drawing text.
"""
DRAW_CAPTION: Literal[64]
"""
specifies a mouse pointer which symbolizes drawing a text caption.
"""
CHART: Literal[65]
"""
specifies a mouse pointer which symbolizes a chart.
"""
DETECTIVE: Literal[66]
"""
specifies a mouse pointer which symbolizes a detective.
"""
PIVOT_COL: Literal[67]
"""
specifies a mouse pointer which symbolizes a pivot column.
"""
PIVOT_ROW: Literal[68]
"""
specifies a mouse pointer which symbolizes a pivot row.
"""
PIVOT_FIELD: Literal[69]
"""
specifies a mouse pointer which symbolizes a pivot field.
"""
CHAIN: Literal[70]
"""
specifies a mouse pointer which symbolizes a chain.
"""
CHAIN_NOTALLOWED: Literal[71]
"""
specifies a mouse pointer which symbolizes \"chaining not allowed\".
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration
from .hierarchy_element import HierarchyElement as HierarchyElement_6fb410e9
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_localizable import XLocalizable as XLocalizable_aee00b64
from ..util.x_changes_notifier import XChangesNotifier as XChangesNotifier_e1b50d17

class AccessRootElement(HierarchyElement_6fb410e9, XComponent_98dc0ab5, XLocalizable_aee00b64, XChangesNotifier_e1b50d17):
    """
    Service Class

    provides information about the root element of a hierarchy and about the hierarchy as a whole.
    
    Provides information about the element and the whole hierarchy. Allows controlling the lifetime of the hierarchy. Allows observing changes in the hierarchy as a whole.
    
    When access to a hierarchy is first obtained from a factory or provider, this is the initial object that is created by the factory. It represents the root of the accessible part of the hierarchy.
    
    NOTE: In this description \"hierarchy\" may actually designate a part or fragment of a larger hierarchy. It is that part that is rooted in the element represented by an implementation of this service and that is accessible starting from this element.
    
    Generally it is not possible to navigate the parent or siblings, if any, of this element, so com.sun.star.container.XChild is not supported.

    See Also:
        `API AccessRootElement <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1AccessRootElement.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration.backend
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .template_identifier import TemplateIdentifier as TemplateIdentifier_2aaa14b5

class XUpdateHandler(XInterface_8f010a43):
    """
    receives a description of a configuration update or layer as a sequence of events.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XUpdateHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XUpdateHandler.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.configuration.backend.XUpdateHandler']

    def addOrReplaceNode(self, aName: str, aAttributes: int) -> None:
        """
        receives notification that a node is started as a new item.
        
        The current node must be a set and a preexisting item (if any) must be removable.
        
        The new item will be created from the default template of the set.
        
        Subsequent calls describe the difference from the template of properties, items or members of the node until a matching call to XUpdateHandler.endNode() is encountered.
        
        The value is a combination of NodeAttribute flags. Note that NodeAttribute.FUSE has an impact on the semantics of this method.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def addOrReplaceNodeFromTemplate(self, aName: str, aAttributes: int, aTemplate: 'TemplateIdentifier_2aaa14b5') -> None:
        """
        receives notification that a node is started as a new item based on a particular template.
        
        The current node must be a set and a preexisting item (if any) must be removable.
        
        Subsequent calls describe the difference from the template of properties or members of the node until a matching call to XUpdateHandler.endNode() is encountered.
        
        The value is a combination of NodeAttribute flags. Note that NodeAttribute.FUSE has an impact on the semantics of this method.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def addOrReplaceProperty(self, aName: str, aAttributes: int, aType: object) -> None:
        """
        receives notification that a property having a value of VOID is added to the current node.
        
        The current node must be extensible and a preexisting property (if any) must be removable in this layer.
        
        The value is a combination of NodeAttribute flags and may also contain the SchemaAttribute.REQUIRED flag.
        
        NodeAttribute.MANDATORY need not be set, as dynamic properties always are mandatory in subsequent layers.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def addOrReplacePropertyWithValue(self, aName: str, aAttributes: int, aValue: object) -> None:
        """
        receives notification that a property having a non-NULL value is added to the current node.
        
        The current node must be extensible and a preexisting property (if any) must be removable in this layer.
        
        The value is a combination of NodeAttribute flags and may also contain the SchemaAttribute.REQUIRED flag.
        
        NodeAttribute.MANDATORY need not be set, as dynamic properties always are mandatory in subsequent layers.
        
        The value also determines the type. Therefore the value must not be VOID.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def endNode(self) -> None:
        """
        receives notification that a node modification is complete.
        
        Must match the last open call to XUpdateHandler.modifyNode(), XUpdateHandler.addOrReplaceNode() or XUpdateHandler.addOrReplaceNodeFromTemplate().
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def endProperty(self) -> None:
        """
        receives notification that a property modification is complete.
        
        Must match the last open call to XUpdateHandler.modifyProperty().
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def endUpdate(self) -> None:
        """
        receives notification that the current update description is complete.
        
        Must match a previous call to XUpdateHandler.startUpdate().
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def modifyNode(self, aName: str, aAttributes: int, aAttributeMask: int, bReset: bool) -> None:
        """
        receives notification that a modification of a node is started.
        
        Subsequent calls describe changes to properties and items or members of the node until a matching call to XUpdateHandler.endNode() is encountered.
        
        The value is a combination of NodeAttribute flags.
        
        Only attributes which are selected in aAttributeMask are changed.
        
        The value is a combination of NodeAttribute flags.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def modifyProperty(self, aName: str, aAttributes: int, aAttributeMask: int, aType: object) -> None:
        """
        receives notification that modification of an existing property is started.
        
        Subsequent calls describe changes to the value(s) of the property until a matching call to XUpdateHandler.endProperty() is encountered.
        
        The value is a combination of NodeAttribute flags.
        
        Only attributes which are selected in aAttributeMask are changed.
        
        NodeAttribute.MANDATORY need not be set and can't be removed, as dynamic properties always are mandatory in subsequent layers.
        
        The value is a combination of NodeAttribute flags.
        
        A VOID type can be used to signify that the type is unknown and should not be recorded.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def removeNode(self, aName: str) -> None:
        """
        receives notification that an item is to be dropped from a set.
        
        The current node must be a set and the item must be removable.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def removeProperty(self, aName: str) -> None:
        """
        receives notification that a property is dropped from the current node.
        
        The current node must be extensible and the property removable.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def resetProperty(self, aName: str) -> None:
        """
        receives notification that a property is reset to its default state.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def resetPropertyValue(self) -> None:
        """
        receives notification that the value of the current property should be reset to its default.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def resetPropertyValueForLocale(self, aLocale: str) -> None:
        """
        receives notification that the value of the current property for a specific locale should be reset to its default.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def setPropertyValue(self, aValue: object) -> None:
        """
        receives notification about a change to the value of the current property.
        
        The value must match the type of the existing property. If the property does not have the SchemaAttribute.REQUIRED flag set, the value can be VOID.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def setPropertyValueForLocale(self, aValue: object, aLocale: str) -> None:
        """
        receives notification about a change to the value of the current property for a specific locale.
        
        The value must match the type of the existing property. If the property does not have the SchemaAttribute.REQUIRED flag set, the value can be VOID.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def startUpdate(self) -> None:
        """
        receives notification that an update or description is started.
        
        Some implementations can only detect this when executing XUpdateHandler.endUpdate()

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.embed
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_storage import XStorage as XStorage_8e460a32

class XEmbedObjectFactory(XInterface_8f010a43):
    """
    allows to create and initialize a new embedded object of specified type.
    
    This interface provides user with full control over object creation.

    See Also:
        `API XEmbedObjectFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XEmbedObjectFactory.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.embed.XEmbedObjectFactory']

    def createInstanceUserInit(self, aClassID: 'typing.Tuple[int, ...]', sClassName: str, xStorage: 'XStorage_8e460a32', sEntName: str, nEntryConnectionMode: int, aArgs: 'typing.Tuple[PropertyValue_c9610c73, ...]', aObjectArgs: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> 'XInterface_8f010a43':
        """
        creates a new object and transport parameters for persistent initialization.
        
        This method can be used to have a full control over persistence initialization of an object.
        
        If the service implementation does not support XEmbedObjectCreator interface, it must accept the empty aClassID parameter in case of loading from existing entry.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.document
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class CmisProperty(object):
    """
    Struct Class

    specifies a CMIS property.

    See Also:
        `API CmisProperty <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1document_1_1CmisProperty.html>`_
    """
    typeName: Literal['com.sun.star.document.CmisProperty']

    def __init__(self, Id: typing.Optional[str] = ..., Name: typing.Optional[str] = ..., Type: typing.Optional[str] = ..., Updatable: typing.Optional[bool] = ..., Required: typing.Optional[bool] = ..., MultiValued: typing.Optional[bool] = ..., OpenChoice: typing.Optional[bool] = ..., Choices: typing.Optional[object] = ..., Value: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Id (str, optional): Id value.
            Name (str, optional): Name value.
            Type (str, optional): Type value.
            Updatable (bool, optional): Updatable value.
            Required (bool, optional): Required value.
            MultiValued (bool, optional): MultiValued value.
            OpenChoice (bool, optional): OpenChoice value.
            Choices (object, optional): Choices value.
            Value (object, optional): Value value.
        """


    @property
    def Id(self) -> str:
        """
        unique ID of the Cmis property
        """


    @property
    def Name(self) -> str:
        """
        specifies the display name of the CMIS property.
        """


    @property
    def Type(self) -> str:
        """
        type of the property
        """


    @property
    def Updatable(self) -> bool:
        """
        specifies if the property is updatable.
        """


    @property
    def Required(self) -> bool:
        """
        specifies if the property is required and can not be empty.
        """


    @property
    def MultiValued(self) -> bool:
        """
        specifies if the property has multiple value
        """


    @property
    def OpenChoice(self) -> bool:
        """
        specifies if the property value can be freely set or is restricted from a list of choices.
        """


    @property
    def Choices(self) -> object:
        """
        specifies the possible choices of the values.
        """


    @property
    def Value(self) -> object:
        """
        specifies value of the property
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from .x_accessible import XAccessible as XAccessible_1cbc0eb6

class Accessible(XAccessible_1cbc0eb6):
    """
    Service Class

    Every class has to support this service in order to be accessible.
    
    It provides the means to derive a XAccessibleContext object–which may but usually is not the same object as the object that supports the XAccessible interface–that provides the actual information that is needed to make it accessible.
    
    Service Accessible is just a wrapper for the interface XAccessible. See the interface's documentation for more information.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API Accessible <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1accessibility_1_1Accessible.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdbc
from .connection_properties import ConnectionProperties as ConnectionProperties_1a9f0ee1

class ODBCConnectionProperties(ConnectionProperties_1a9f0ee1):
    """
    Service Class

    represents the properties for an ODBC connection (session) with a specific database.
    
    These properties can be used when calling the method com.sun.star.sdbc.XDriver.connect() or com.sun.star.sdbc.XDriverManager.getConnectionWithInfo().
    
    The properties for a connection contain additional information about how to connect to a database and how to control the behavior of the resulting connection should be.

    See Also:
        `API ODBCConnectionProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1ODBCConnectionProperties.html>`_
    """
    @property
    def AutoRetrievingStatement(self) -> str:
        """
        specifies the statement which should be executed when asking an \"INSERT\" statement for the XGeneratedResultSet (future concept) interface.
        """
    @property
    def CharSet(self) -> str:
        """
        specifies the encoding to use to translate the backend data
        
        See the IANA character set list for a list of valid values.
        """
    @property
    def IsAutoRetrievingEnabled(self) -> bool:
        """
        specifies if retrieving of auto generated values should be enabled or not.
        
        If TRUE than the statement will support the XGeneratedResultSet (future concept) interface, otherwise not.
        """
    @property
    def ParameterNameSubstitution(self) -> bool:
        """
        should the parameter \"?\" in prepared statement be substituted with an distinct name
        """
    @property
    def Silent(self) -> bool:
        """
        Silent - should the connection be silent.
        
        No user interaction while creating the connection.
        """
    @property
    def Timeout(self) -> int:
        """
        the Timeout after which time a timeout should happen
        """
    @property
    def UseCatalog(self) -> bool:
        """
        should the driver should support a catalog.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.packages.zip
from typing_extensions import Literal
"""
Const

defines the constants used by the ZIP interfaces.

See Also:
    `API ZipConstants <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1packages_1_1zip_1_1ZipConstants.html>`_
"""
DEFLATED: Literal[8]
"""
Compression method for the deflate algorithm (the only one currently supported).
"""
NO_COMPRESSION: Literal[0]
"""
Compression level for no compression.
"""
BEST_SPEED: Literal[1]
"""
Compression level for fastest compression.
"""
BEST_COMPRESSION: Literal[9]
"""
Compression level for best compression.
"""
DEFAULT_COMPRESSION: Literal[-1]
"""
Default compression level.
"""
FILTERED: Literal[1]
"""
Compression strategy best used for data consisting mostly of small values with a somewhat random distribution.

Forces more Huffman coding and less string matching.
"""
HUFFMAN_ONLY: Literal[2]
"""
Compression strategy for Huffman coding only.
"""
DEFAULT_STRATEGY: Literal[0]
"""
Default compression strategy.
"""
STORED: Literal[0]
"""
entry is uncompressed
"""
DEF_MEM_LEVEL: Literal[8]
"""
entry is uncompressed
"""
LOCSIG: Literal[67324752]
"""
Header Signature: \"PK\\003\\004\".
"""
EXTSIG: Literal[134695760]
"""
Header Signature: \"PK\\007\\008\".
"""
CENSIG: Literal[33639248]
"""
Header Signature: \"PK\\001\\002\".
"""
ENDSIG: Literal[101010256]
"""
Header Signature: \"PK\\005\\006\".
"""
SPANSIG: Literal[134695760]
"""
Header Signature: \"PK\\007\\008\".
"""
LOCHDR: Literal[30]
"""
LOC header size in bytes (including signatures)
"""
EXTHDR: Literal[16]
"""
EXT header size in bytes (including signatures)
"""
CENHDR: Literal[46]
"""
CEN header size in bytes (including signatures)
"""
ENDHDR: Literal[22]
"""
END header size in bytes (including signatures)
"""
LOCVER: Literal[4]
"""
LOC LOC LOC.

LOC header field \"version needed to extract\" offset
"""
LOCFLG: Literal[6]
"""
LOC header field \"general purpose bit flags\" offset.
"""
LOCHOW: Literal[8]
"""
LOC header field \"compression method\" offset.
"""
LOCTIM: Literal[10]
"""
LOC header field \"modification time\" offset.
"""
LOCCRC: Literal[14]
"""
LOC header field \"CRC of uncompressed data\" offset.
"""
LOCSIZ: Literal[18]
"""
LOC header field \"compressed data size\" offset.
"""
LOCLEN: Literal[22]
"""
LOC header field \"uncompressed data size\" offset.
"""
LOCNAM: Literal[26]
"""
LOC header field \"filename length\" offset.
"""
LOCEXT: Literal[28]
"""
LOC header field \"extra field length\" offset.
"""
EXTCRC: Literal[4]
"""
EXT header field \"CRC of uncompressed data\" offsets.
"""
EXTSIZ: Literal[8]
"""
EXT header field \"compressed size\" offsets.
"""
EXTLEN: Literal[12]
"""
EXT header field \"uncompressed size\" offsets.
"""
CENVEM: Literal[4]
"""
CEN header field \"version made by\" offset.
"""
CENVER: Literal[6]
"""
CEN header field \"version needed to extract\" offset.
"""
CENFLG: Literal[8]
"""
CEN header field \"general purpose bit flags\" offset.
"""
CENHOW: Literal[10]
"""
CEN header field \"compression method\" offset.
"""
CENTIM: Literal[12]
"""
CEN header field \"modification time\" offset.
"""
CENDAT: Literal[14]
"""
CEN header field \"modification time\" offset.
"""
CENCRC: Literal[16]
"""
CEN header field \"CRC of uncompressed data\" offset.
"""
CENSIZ: Literal[20]
"""
CEN header field \"compressed size\" offset.
"""
CENLEN: Literal[24]
"""
CEN header field \"uncompressed size\" offset.
"""
CENNAM: Literal[28]
"""
CEN header field \"length of filename\" offset.
"""
CENEXT: Literal[30]
"""
CEN header field \"length of extra field\" offset.
"""
CENCOM: Literal[32]
"""
CEN header field \"file comment length\" offset.
"""
CENDSK: Literal[34]
"""
CEN header field \"disk number start\" offset.
"""
CENATT: Literal[36]
"""
CEN header field \"internal file attributes\" offset.
"""
CENATX: Literal[38]
"""
CEN header field \"external file attributes\" offset.
"""
CENOFF: Literal[42]
"""
CEN header field \"offset of local header\" offset.
"""
ENDSUB: Literal[8]
"""
END header field \"number of entries on this disk\" offset.
"""
ENDTOT: Literal[10]
"""
END header field \"total number of entries\" offset.
"""
ENDSIZ: Literal[12]
"""
END header field \"central directory size\" offset.
"""
ENDOFF: Literal[16]
"""
END header field \"central directory offset\" offset.
"""
ENDCOM: Literal[20]
"""
END header field \"size of zip file comment\" offset.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart2
import typing
from ..beans.property_set import PropertySet as PropertySet_b0e70ba2
from ..drawing.fill_properties import FillProperties as FillProperties_f1200da8
if typing.TYPE_CHECKING:
    from ..awt.gradient import Gradient as Gradient_7a8a0982
    from ..awt.size import Size as Size_576707ef
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from .data_point_label import DataPointLabel as DataPointLabel_dd530cb0
    from .relative_position import RelativePosition as RelativePosition_fae10ddd
    from .symbol import Symbol as Symbol_83c109c2
    from .x_data_point_custom_label_field import XDataPointCustomLabelField as XDataPointCustomLabelField_94771167
    from ..drawing.bitmap_mode import BitmapMode as BitmapMode_bced0bd6
    from ..drawing.fill_style import FillStyle as FillStyle_b1460b8c
    from ..drawing.hatch import Hatch as Hatch_859b09dc
    from ..drawing.line_dash import LineDash as LineDash_a54e0afc
    from ..drawing.line_style import LineStyle as LineStyle_b1600b8d
    from ..drawing.rectangle_point import RectanglePoint as RectanglePoint_f0ff0d93

class DataPointProperties(PropertySet_b0e70ba2, FillProperties_f1200da8):
    """
    Service Class

    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API DataPointProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1DataPointProperties.html>`_
    """
    @property
    def CustomLabelFields(self) -> 'typing.Tuple[XDataPointCustomLabelField_94771167, ...]':
        """
        specifies a text with possible fields that is used as a data point label, if set then Label property is ignored
        
        **since**
        
            LibreOffice 6.1
        """
    @property
    def BorderColor(self) -> int:
        """
        Is used for borders around filled objects.
        
        See LineColor.
        """
    @property
    def BorderDash(self) -> 'LineDash_a54e0afc':
        """
        Is used for borders around filled objects.
        
        See LineDash.
        """
    @property
    def BorderDashName(self) -> str:
        """
        The name of a dash that can be found in the com.sun.star.container.XNameContainer \"com.sun.star.drawing.LineDashTable\", that can be created via the com.sun.star.uno.XMultiServiceFactory of the ChartDocument.
        """
    @property
    def BorderStyle(self) -> 'LineStyle_b1600b8d':
        """
        Is used for borders around filled objects.
        
        See LineStyle.
        """
    @property
    def BorderTransparency(self) -> int:
        """
        Is used for borders around filled objects.
        
        See LineTransparence.
        """
    @property
    def BorderWidth(self) -> int:
        """
        Is used for borders around filled objects.
        
        See LineWidth.
        """
    @property
    def Color(self) -> int:
        """
        points to a style that also supports this service (but not this property) that is used as default, if the PropertyState of a property is DEFAULT_VALUE.
        
        This is the main color of a data point.
        
        For charts with filled areas, like bar-charts, this should map to the FillColor of the objects. For line-charts this should map to the LineColor property.
        """
    @property
    def CustomLabelPosition(self) -> 'RelativePosition_fae10ddd':
        """
        Custom position on the page associated to the CUSTOM label placement.
        
        **since**
        
            LibreOffice 7.0
        """
    @property
    def ErrorBarX(self) -> 'XPropertySet_bc180bfa':
        """
        If void, no error bars are shown for the data point in x-direction.
        
        The com.sun.star.beans.XPropertySet must support the service ErrorBar.
        """
    @property
    def ErrorBarY(self) -> 'XPropertySet_bc180bfa':
        """
        If void, no error bars are shown for the data point in y-direction.
        
        The com.sun.star.beans.XPropertySet must support the service ErrorBar.
        """
    @property
    def FillBackground(self) -> bool:
        """
        If TRUE, fills the background of a hatch with the color given in the Color property.
        """
    @property
    def FillBitmapLogicalSize(self) -> bool:
        """
        specifies if the size is given in percentage or as an absolute value.
        
        If this is TRUE, the properties FillBitmapSizeX and FillBitmapSizeY contain the size of the tile in percent of the size of the original bitmap. If this is FALSE, the size of the tile is specified with 1/100th mm.
        """
    @property
    def FillBitmapMode(self) -> 'BitmapMode_bced0bd6':
        """
        this enum selects how an area is filled with a single bitmap.
        """
    @property
    def FillBitmapName(self) -> str:
        """
        """
    @property
    def FillBitmapOffsetX(self) -> int:
        """
        This is the horizontal offset where the tile starts.
        
        It is given in percent in relation to the width of the bitmap.
        """
    @property
    def FillBitmapOffsetY(self) -> int:
        """
        This is the vertical offset where the tile starts.
        
        It is given in percent in relation to the width of the bitmap.
        """
    @property
    def FillBitmapPositionOffsetX(self) -> int:
        """
        Every second line of tiles is moved the given percent of the width of the bitmap.
        """
    @property
    def FillBitmapPositionOffsetY(self) -> int:
        """
        Every second row of tiles is moved the given percent of the width of the bitmap.
        """
    @property
    def FillBitmapRectanglePoint(self) -> 'RectanglePoint_f0ff0d93':
        """
        The RectanglePoint specifies the position inside of the bitmap to use as the top left position for rendering.
        """
    @property
    def FillBitmapSizeX(self) -> int:
        """
        This is the width of the tile for filling.
        
        Depending on the property FillBitmapLogicalSize, this is either relative or absolute.
        """
    @property
    def FillBitmapSizeY(self) -> int:
        """
        This is the height of the tile for filling.
        
        Depending on the property FillBitmapLogicalSize, this is either relative or absolute.
        """
    @property
    def FillStyle(self) -> 'FillStyle_b1460b8c':
        """
        This enumeration selects the style with which the area will be filled.
        """
    @property
    def Geometry3D(self) -> int:
        """
        describes the geometry of a 3 dimensional data point.
        
        Number is one of constant group DataPointGeometry3D.
        
        This is especially used for 3D bar-charts.
        
        CUBOID==0 CYLINDER==1 CONE==2 PYRAMID==3 CUBOID==else
        """
    @property
    def Gradient(self) -> 'Gradient_7a8a0982':
        """
        """
    @property
    def GradientName(self) -> str:
        """
        """
    @property
    def Hatch(self) -> 'Hatch_859b09dc':
        """
        """
    @property
    def HatchName(self) -> str:
        """
        """
    @property
    def Label(self) -> 'DataPointLabel_dd530cb0':
        """
        """
    @property
    def LabelPlacement(self) -> int:
        """
        specifies a relative position for the data label
        """
    @property
    def LabelSeparator(self) -> str:
        """
        specifies a string that is used to separate the parts of a data label (caption)
        """
    @property
    def LineDash(self) -> 'LineDash_a54e0afc':
        """
        Is only used for line-chart types.
        """
    @property
    def LineDashName(self) -> str:
        """
        The name of a dash that can be found in the com.sun.star.container.XNameContainer \"com.sun.star.drawing.LineDashTable\", that can be created via the com.sun.star.uno.XMultiServiceFactory of the ChartDocument.
        """
    @property
    def LineStyle(self) -> 'LineStyle_b1600b8d':
        """
        """
    @property
    def LineWidth(self) -> int:
        """
        Is only used for line-chart types.
        """
    @property
    def NumberFormat(self) -> int:
        """
        specifies a number format for the display of the value in the data label
        """
    @property
    def Offset(self) -> float:
        """
        describes a value by which a data point is moved from its default position in percent of the maximum allowed distance.
        
        This is especially useful for the explosion of pie-chart segments.
        """
    @property
    def PercentDiagonal(self) -> int:
        """
        A value between 0 and 100 indicating the percentage how round an edge should be.
        """
    @property
    def PercentageNumberFormat(self) -> int:
        """
        specifies a number format for the display of the percentage value in the data label
        """
    @property
    def ReferencePageSize(self) -> 'Size_576707ef':
        """
        The size of the page at the moment when the font size for data labels was set.
        
        This size is used to resize text in the view when the size of the page has changed since the font sizes were set (automatic text scaling).
        """
    @property
    def ShowErrorBox(self) -> bool:
        """
        In case ErrorBarX and ErrorBarY both are set, and error bars are shown, a box spanning all error-indicators is rendered.
        """
    @property
    def Symbol(self) -> 'Symbol_83c109c2':
        """
        """
    @property
    def TextWordWrap(self) -> bool:
        """
        specifies if the text of a data label (caption) must be wrapped
        
        **since**
        
            LibreOffice 5.1
        """
    @property
    def Transparency(self) -> int:
        """
        This is the main transparency value of a data point.
        
        For charts with filled areas, like bar-charts, this should map to the FillTransparence of the objects. For line-charts this should map to the LineTransparence property.
        """
    @property
    def TransparencyGradient(self) -> 'Gradient_7a8a0982':
        """
        This describes the transparency of the fill area as a gradient.
        """
    @property
    def TransparencyGradientName(self) -> str:
        """
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing.framework
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_resource import XResource as XResource_3bcd0f90
    from .x_resource_id import XResourceId as XResourceId_5be3103d

class XResourceFactory(ABC):
    """
    Factory and possibly cache for creating and releasing resources.
    
    A resource factory is created and used by the XConfigurationController object.
    
    A factory may want to implement a cache to reuse previously released resources.

    See Also:
        `API XResourceFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XResourceFactory.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.framework.XResourceFactory']

    def createResource(self, xResourceId: 'XResourceId_5be3103d') -> 'XResource_3bcd0f90':
        """
        Create a resource for the given XResourceId object.
        
        Valid values are those for which the factory has previously been registered at the XConfigurationController
        
        .

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def releaseResource(self, xResource: 'XResource_3bcd0f90') -> None:
        """
        Call this method to tell a factory that the given resource is no longer in use.
        
        The factory can decide whether to destroy the resource or to keep it in a cache in order to reuse it later.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe

class XDataContainer(XIndexContainer_1c040ebe):
    """
    specifies a container for (binary) data.
    
    A data container may contain data and/or other data containers. A typical container with children is a MIME message with attachments.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XDataContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XDataContainer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XDataContainer']

    def getContentType(self) -> str:
        """
        returns the content type (MIME Type) of the data container.
        """
    def getData(self) -> 'typing.Tuple[int, ...]':
        """
        returns the data of the data container.
        """
    def getDataURL(self) -> str:
        """
        Deprecated.
        
        Do not use!
        """
    def setContentType(self, aType: str) -> None:
        """
        sets the content type (MIME Type) of the data container.
        """
    def setData(self, aData: 'typing.Tuple[int, ...]') -> None:
        """
        sets the data of the data container.
        """
    def setDataURL(self, aURL: str) -> None:
        """
        Deprecated.
        
        Do not use!
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from ..container.x_child import XChild as XChild_a6390b07
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..rdf.x_metadatable import XMetadatable as XMetadatable_a3000af0
from .text_content import TextContent as TextContent_a6810b4d

class InContentMetadata(TextContent_a6810b4d, XChild_a6390b07, XEnumerationAccess_4bac0ffc, XMetadatable_a3000af0):
    """
    Service Class

    is a TextContent that can be used to attach RDF metadata to a range of text.
    
    **since**
    
        OOo 3.2

    See Also:
        `API InContentMetadata <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1InContentMetadata.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..awt.point import Point as Point_5fb2085e
from .alignment import Alignment as Alignment_b1400b93
from .escape_direction import EscapeDirection as EscapeDirection_fdc50de6


class GluePoint2(object):
    """
    Struct Class

    This struct defines the attributes of a glue point.
    
    A glue point is a position inside a drawing shape where an edge of a connector shape can be connected.

    See Also:
        `API GluePoint2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1GluePoint2.html>`_
    """
    typeName: Literal['com.sun.star.drawing.GluePoint2']

    def __init__(self, Position: typing.Optional[Point_5fb2085e] = ..., IsRelative: typing.Optional[bool] = ..., PositionAlignment: typing.Optional[Alignment_b1400b93] = ..., Escape: typing.Optional[EscapeDirection_fdc50de6] = ..., IsUserDefined: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Position (Point, optional): Position value.
            IsRelative (bool, optional): IsRelative value.
            PositionAlignment (Alignment, optional): PositionAlignment value.
            Escape (EscapeDirection, optional): Escape value.
            IsUserDefined (bool, optional): IsUserDefined value.
        """


    @property
    def Position(self) -> Point_5fb2085e:
        """
        This is the position of this glue point.
        
        Depending on the flag IsRelative, this is either in 1/100cm or in 1/100%.
        """


    @property
    def IsRelative(self) -> bool:
        """
        if this flag is set to true, the position of this glue point is given in 1/100% values instead of 1/100cm.
        """


    @property
    def PositionAlignment(self) -> Alignment_b1400b93:
        """
        if this glue points position is not relative, this enum specifies the vertical and horizontal alignment of this point.
        
        The alignment specifies how the glue point is moved if the shape is resized.
        """


    @property
    def Escape(self) -> EscapeDirection_fdc50de6:
        """
        this member specifies the escape direction for a glue point.
        
        The escape direction is the direction the connecting line escapes the shape.
        """


    @property
    def IsUserDefined(self) -> bool:
        """
        if this flag is set to false, this is a default glue point.
        
        Some shapes may have default glue points attached to them which cannot be altered or removed.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.auth
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XSSOContext(XInterface_8f010a43):
    """
    Base SSO security context representation.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XSSOContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1auth_1_1XSSOContext.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.auth.XSSOContext']

    def getMechanism(self) -> str:
        """
        retrieves the mechanism associated with the context.
        """
    def getMutual(self) -> bool:
        """
        retrieves whether or not the context supports mutual authentication
        """
    def getSource(self) -> str:
        """
        retrieves the principal name of the source/initiator of the context.
        
        In the case of an acceptor side security context, the source principal name is available only after the initiator has been authenticated.
        """
    def getTarget(self) -> str:
        """
        retrieves the principal name of the target/acceptor of the context.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.datatransfer.dnd
# Libre Office Version: 7.2
from typing_extensions import Literal
from .drag_source_event import DragSourceEvent as DragSourceEvent_8ccf115c
from ...uno.x_interface import XInterface as XInterface_8f010a43
from .x_drag_source_context import XDragSourceContext as XDragSourceContext_c2661297
from .x_drag_source import XDragSource as XDragSource_49900fb2
import typing


class DragSourceDropEvent(DragSourceEvent_8ccf115c):
    """
    Struct Class

    The DragSourceDropEvent is delivered from an object that implements XDragSourceContext to its currently registered drag source listener's.
    
    It contains sufficient information for the originator of the operation to provide appropriate feedback to the end user when the operation completes.

    See Also:
        `API DragSourceDropEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1DragSourceDropEvent.html>`_
    """
    typeName: Literal['com.sun.star.datatransfer.dnd.DragSourceDropEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., DragSourceContext: typing.Optional[XDragSourceContext_c2661297] = ..., DragSource: typing.Optional[XDragSource_49900fb2] = ..., DropAction: typing.Optional[int] = ..., DropSuccess: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            DragSourceContext (XDragSourceContext, optional): DragSourceContext value.
            DragSource (XDragSource, optional): DragSource value.
            DropAction (int, optional): DropAction value.
            DropSuccess (bool, optional): DropSuccess value.
        """


    @property
    def DropAction(self) -> int:
        """
        The action performed by the target on the subject of the drop.
        """


    @property
    def DropSuccess(self) -> bool:
        """
        Indicates if the drop was successful.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.document
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from ..i18n.x_forbidden_characters import XForbiddenCharacters as XForbiddenCharacters_df60e2d

class Settings(XPropertySet_bc180bfa):
    """
    Service Class

    describes properties that apply to the whole document of any application.
    
    For application specific settings, please refer to the individual services.
    
    **since**
    
        LibreOffice 6.2

    See Also:
        `API Settings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1document_1_1Settings.html>`_
    """
    @property
    def PrinterSetup(self) -> 'typing.Tuple[int, ...]':
        """
        platform and driver dependent printer setup data.
        
        This property serves to capture the current printer setup settings, such as paper tray, printer options, etc. The data can typically be interpreted only by the system that generated it. The PrinterSetup property may be used to save and restore the user's printer settings.
        """
    @property
    def AddExternalLeading(self) -> bool:
        """
        layout engine should add value of a Font's \"external leading\" attribute to the line spacing.
        """
    @property
    def ApplyUserData(self) -> bool:
        """
        specifies if the user-specific settings saved within a document should be loaded with the document.
        """
    @property
    def AutoCalculate(self) -> bool:
        """
        """
    @property
    def BitmapTableURL(self) -> str:
        """
        """
    @property
    def CharacterCompressionType(self) -> int:
        """
        specifies the compression (character spacing) type used for Asian characters.
        """
    @property
    def ColorTableURL(self) -> str:
        """
        contains the URL that points to a color table (file extension .soc) that will be used for showing a palette in dialogs using colors.
        """
    @property
    def CurrentDatabaseCommand(self) -> str:
        """
        a string value, specifying the name of the object displayed currently (or the SQL statement used).
        """
    @property
    def CurrentDatabaseCommandType(self) -> int:
        """
        determines the interpretation of the property DataTableName.
        """
    @property
    def CurrentDatabaseDataSource(self) -> str:
        """
        The name of the globally registered com.sun.star.sdb.DataSource from which the current data is taken.
        
        The data source can e.g. be used for feeding a form letter.
        """
    @property
    def DashTableURL(self) -> str:
        """
        """
    @property
    def DefaultTabStop(self) -> int:
        """
        """
    @property
    def EmbedAsianScriptFonts(self) -> bool:
        """
        Whether to embed Asian script fonts.
        
        **since**
        
            LibreOffice 6.2
        """
    @property
    def EmbedComplexScriptFonts(self) -> bool:
        """
        Whether to embed Complex script fonts.
        
        **since**
        
            LibreOffice 6.2
        """
    @property
    def EmbedFonts(self) -> bool:
        """
        Whether to embed fonts used by the document (see e.g.
        
        handling of OOXML embedRegular etc.)
        
        **since**
        
            LibreOffice 4.0
        """
    @property
    def EmbedLatinScriptFonts(self) -> bool:
        """
        Whether to embed Latin script fonts.
        
        **since**
        
            LibreOffice 6.2
        """
    @property
    def EmbedOnlyUsedFonts(self) -> bool:
        """
        Whether to embed only the fonts that are used in the document.
        
        **since**
        
            LibreOffice 6.2
        """
    @property
    def EmbedSystemFonts(self) -> bool:
        """
        Whether to embed also system fonts used by the document.
        
        Does not have any effect if EmbedFonts is false.
        
        **since**
        
            LibreOffice 4.0
        """
    @property
    def FieldAutoUpdate(self) -> bool:
        """
        specifies if fields in text documents are updated automatically.
        """
    @property
    def ForbiddenCharacters(self) -> 'XForbiddenCharacters_df60e2d':
        """
        gives access to the set of forbidden characters.
        """
    @property
    def GradientTableURL(self) -> str:
        """
        """
    @property
    def HatchTableURL(self) -> str:
        """
        """
    @property
    def IsKernAsianPunctuation(self) -> bool:
        """
        specifies if kerning is applied to Asian punctuation.
        
        Applies only if kerning is enabled.
        """
    @property
    def IsPrintBooklet(self) -> bool:
        """
        determines if the document will be printed as a booklet (brochure), i.e., two document pages are put together on one physical page, such that you can fold the print result and get a booklet.
        
        Note, that you have to print in duplex mode, if both, IsPrintBookletFront and IsPrintBookletBack are set to TRUE.
        """
    @property
    def IsPrintBookletBack(self) -> bool:
        """
        is only effective, if IsPrintBooklet is TRUE.
        
        If this property is also TRUE, only the backs of the pages of your booklet are printed.
        
        This is especially useful, if your printer does not supply duplex printing.
        """
    @property
    def IsPrintBookletFront(self) -> bool:
        """
        is only effective, if IsPrintBooklet is TRUE.
        
        If this property is also TRUE, only the fronts of the pages of your booklet are printed.
        
        This is especially useful, if your printer does not supply duplex printing.
        """
    @property
    def LineEndTableURL(self) -> str:
        """
        """
    @property
    def LinkUpdateMode(self) -> int:
        """
        specifies the update mode for links when loading text documents.
        
        For supported values see the constants group LinkUpdateModes.
        """
    @property
    def PrintQuality(self) -> int:
        """
        how printing uses color.
        """
    @property
    def PrinterIndependentLayout(self) -> int:
        """
        forbid use of printer metrics for layout
        
        For supported values see the constants group PrinterIndependentLayout.
        """
    @property
    def PrinterName(self) -> str:
        """
        printer used by the document.
        """
    @property
    def SaveVersionOnClose(self) -> bool:
        """
        specifies if a new version is created if a document has been modified and you want to close it.
        """
    @property
    def UpdateFromTemplate(self) -> bool:
        """
        specifies if the document should be updated when the template it was created from changes.
        
        Applies only for documents that were created from a template.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .note_print_mode import NotePrintMode as NotePrintMode_bdae0bf5

class PrintSettings(ABC):
    """
    Service Class

    These properties describe the printing of the content of a text document.

    See Also:
        `API PrintSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1PrintSettings.html>`_
    """
    @property
    def PrintAnnotationMode(self) -> 'NotePrintMode_bdae0bf5':
        """
        determines how notes are printed.
        """
    @property
    def PrintBlackFonts(self) -> bool:
        """
        determines if characters are always printed in black.
        """
    @property
    def PrintControls(self) -> bool:
        """
        determines if control shapes are printed.
        """
    @property
    def PrintDrawings(self) -> bool:
        """
        determines if shapes are printed.
        """
    @property
    def PrintEmptyPages(self) -> bool:
        """
        determines if automatically inserted empty pages are printed.
        """
    @property
    def PrintFaxName(self) -> str:
        """
        contains the name of the fax.
        """
    @property
    def PrintGraphics(self) -> bool:
        """
        determines if graphic objects are printed
        """
    @property
    def PrintLeftPages(self) -> bool:
        """
        determines if left pages are printed.
        """
    @property
    def PrintPageBackground(self) -> bool:
        """
        determines if the background color / background graphic of pages is printed.
        """
    @property
    def PrintPaperFromSetup(self) -> bool:
        """
        specifies if the printer paper tray selection of the system printer is used.
        
        If com.sun.star.view.PrintSettings.PaperFromSetup is FALSE, then the paper tray selection of the page styles is used.
        """
    @property
    def PrintProspect(self) -> bool:
        """
        determines if prospect printing is used.
        """
    @property
    def PrintReversed(self) -> bool:
        """
        determines if the pages are printed in the reverse order, starting with the last page.
        """
    @property
    def PrintRightPages(self) -> bool:
        """
        determines if right pages are printed.
        """
    @property
    def PrintTables(self) -> bool:
        """
        determines if text tables are printed.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_draw_page import XDrawPage as XDrawPage_b07a0b57
    from .x_draw_pages import XDrawPages as XDrawPages_bc440bca

class XDrawPageExpander(XInterface_8f010a43):
    """
    is implemented by documents that can expand the contents of a summary on a DrawPage into a collection of DrawPages.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XDrawPageExpander <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPageExpander.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.XDrawPageExpander']

    def expand(self, xPage: 'XDrawPage_b07a0b57') -> 'XDrawPages_bc440bca':
        """
        creates a collection of DrawPages from the summary inside the given DrawPage and adds them to the same model as the source DrawPage.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.graphic
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from .x_graphic import XGraphic as XGraphic_a4da0afc
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4

class XGraphicRasterizer(XInterface_8f010a43):
    """
    This interfaces exposes the initialize and a rasterize method to rasterize a given data stream to a pixel graphic.

    See Also:
        `API XGraphicRasterizer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1graphic_1_1XGraphicRasterizer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.graphic.XGraphicRasterizer']

    def initializeData(self, DataStream: 'XInputStream_98d40ab4', DPIX: int, DPIY: int, DefaultSizePixel: 'Size_576707ef') -> bool:
        """
        Initializing the rasterizer.
        
        This method could also be used to determine, if the provided data is able to be rasterized by the implementation. The implementation should take care of this feature as well as setting the default image size in pixel within the given output parameter.
        
        0
        
        is given, a horizontal default resolution of 72 DPI is used.
        
        0
        
        is given, a vertical default resolution of 72 DPI is used.
        
        In case no default size can be determined during initialization, a default pixel size of 0,0 is returned. In this case, the caller needs to assume a default pixel size, appropriate for the calling context.

        * ``DefaultSizePixel`` is an out direction argument.
        """
    def rasterize(self, Width: int, Height: int, RotateAngle: float, ShearAngleX: float, ShearAngleY: float, RasterizeProperties: 'PropertyValues_d6470ce6') -> 'XGraphic_a4da0afc':
        """
        Rasterizing the initialized data into a XGraphic container.
        
        The XGraphic container will contain a pixel type graphic after a successful rasterization process
        
        In case of any fault during the rasterization process, the XGraphic container will be empty afterwards and the method will return false
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
import typing
from ..document.office_document import OfficeDocument as OfficeDocument_fecd0df2
from ..document.x_action_lockable import XActionLockable as XActionLockable_cb30e3a
from ..document.x_link_target_supplier import XLinkTargetSupplier as XLinkTargetSupplier_4ac21008
from ..drawing.x_draw_pages_supplier import XDrawPagesSupplier as XDrawPagesSupplier_29650f1e
from ..frame.x_model import XModel as XModel_7a6e095c
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6
from .spreadsheet_document_settings import SpreadsheetDocumentSettings as SpreadsheetDocumentSettings_a1641229
from .x_calculatable import XCalculatable as XCalculatable_c7b30c36
from .x_consolidatable import XConsolidatable as XConsolidatable_e2930d1d
from .x_document_auditing import XDocumentAuditing as XDocumentAuditing_fd650ded
from .x_goal_seek import XGoalSeek as XGoalSeek_99130a84
from .x_spreadsheet_document import XSpreadsheetDocument as XSpreadsheetDocument_2a1f0f30
from ..style.x_style_families_supplier import XStyleFamiliesSupplier as XStyleFamiliesSupplier_4c5a1020
from ..util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier_3afb0fb7
from ..util.x_protectable import XProtectable as XProtectable_b17f0b93
if typing.TYPE_CHECKING:
    from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
    from .x_area_links import XAreaLinks as XAreaLinks_a3ce0af3
    from .x_database_ranges import XDatabaseRanges as XDatabaseRanges_e0690cee
    from .x_label_ranges import XLabelRanges as XLabelRanges_bac20bb9
    from .x_named_ranges import XNamedRanges as XNamedRanges_bb030bbe

class SpreadsheetDocument(OfficeDocument_fecd0df2, SpreadsheetDocumentSettings_a1641229, XActionLockable_cb30e3a, XLinkTargetSupplier_4ac21008, XDrawPagesSupplier_29650f1e, XModel_7a6e095c, XMultiServiceFactory_191e0eb6, XCalculatable_c7b30c36, XConsolidatable_e2930d1d, XDocumentAuditing_fd650ded, XGoalSeek_99130a84, XSpreadsheetDocument_2a1f0f30, XStyleFamiliesSupplier_4c5a1020, XNumberFormatsSupplier_3afb0fb7, XProtectable_b17f0b93):
    """
    Service Class

    represents a model component which consists of some settings and one or more spreadsheets.

    See Also:
        `API SpreadsheetDocument <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetDocument.html>`_
    """
    @property
    def AreaLinks(self) -> 'XAreaLinks_a3ce0af3':
        """
        contains the collection of area links in the document.
        """
    @property
    def ColumnLabelRanges(self) -> 'XLabelRanges_bac20bb9':
        """
        contains the collection of column label ranges in the document.
        """
    @property
    def DDELinks(self) -> 'XNameAccess_e2ab0cf6':
        """
        contains the collection of DDE links in the document.
        """
    @property
    def DatabaseRanges(self) -> 'XDatabaseRanges_e0690cee':
        """
        contains the collection of database ranges in the document.
        """
    @property
    def NamedRanges(self) -> 'XNamedRanges_bb030bbe':
        """
        contains the collection of named ranges in the document.
        """
    @property
    def RowLabelRanges(self) -> 'XLabelRanges_bac20bb9':
        """
        contains the collection of row label ranges in the document.
        """
    @property
    def SheetLinks(self) -> 'XNameAccess_e2ab0cf6':
        """
        contains the collection of sheet links in the document.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart
from .x_axis_x_supplier import XAxisXSupplier as XAxisXSupplier_d43a0cb3

class ChartAxisXSupplier(XAxisXSupplier_d43a0cb3):
    """
    Service Class

    has to be supported by charts providing the capabilities of a horizontal axis, i.e., an x-axis.

    See Also:
        `API ChartAxisXSupplier <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartAxisXSupplier.html>`_
    """
    @property
    def HasXAxis(self) -> bool:
        """
        This property determines if the x-axis is shown or hidden.
        """
    @property
    def HasXAxisDescription(self) -> bool:
        """
        Determines if the description of the x-axis is shown or hidden.
        """
    @property
    def HasXAxisGrid(self) -> bool:
        """
        Determines if the major grid of the x-axis is shown or hidden.
        """
    @property
    def HasXAxisHelpGrid(self) -> bool:
        """
        Determines if the minor grid of the x-axis is shown or hidden.
        """
    @property
    def HasXAxisTitle(self) -> bool:
        """
        Determines if the title of the x-axis is shown or hidden.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..io.x_output_stream import XOutputStream as XOutputStream_a4e00b35


class ExportStreamInfo(object):
    """
    Struct Class

    information needed to export an object in mbx format (supplying an output stream to export into).

    See Also:
        `API ExportStreamInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1ExportStreamInfo.html>`_
    """
    typeName: Literal['com.sun.star.ucb.ExportStreamInfo']

    def __init__(self, Target: typing.Optional[XOutputStream_a4e00b35] = ..., ForceBodies: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Target (XOutputStream, optional): Target value.
            ForceBodies (bool, optional): ForceBodies value.
        """


    @property
    def Target(self) -> XOutputStream_a4e00b35:
        """
        the output stream to export into.
        """


    @property
    def ForceBodies(self) -> bool:
        """
        tries hard to make message (document) bodies available for export.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.2
from typing_extensions import Literal
from .currency import Currency as Currency_80230993
import typing


class Currency2(Currency_80230993):
    """
    Struct Class

    Symbols, names, and attributes of a specific currency, returned in a sequence by XLocaleData2.getAllCurrencies2().
    
    It is derived from com.sun.star.i18n.Currency and provides an additional flag for currency entries that are available only for legacy reasons in context of loaded documents that use them, but otherwise should not be offered to the user to be selectable.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API Currency2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1Currency2.html>`_
    """
    typeName: Literal['com.sun.star.i18n.Currency2']

    def __init__(self, ID: typing.Optional[str] = ..., Symbol: typing.Optional[str] = ..., BankSymbol: typing.Optional[str] = ..., Name: typing.Optional[str] = ..., Default: typing.Optional[bool] = ..., UsedInCompatibleFormatCodes: typing.Optional[bool] = ..., DecimalPlaces: typing.Optional[int] = ..., LegacyOnly: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            ID (str, optional): ID value.
            Symbol (str, optional): Symbol value.
            BankSymbol (str, optional): BankSymbol value.
            Name (str, optional): Name value.
            Default (bool, optional): Default value.
            UsedInCompatibleFormatCodes (bool, optional): UsedInCompatibleFormatCodes value.
            DecimalPlaces (int, optional): DecimalPlaces value.
            LegacyOnly (bool, optional): LegacyOnly value.
        """


    @property
    def LegacyOnly(self) -> bool:
        """
        If set, the currency and/or its symbol is only to be used in legacy context.
        
        **since**
        
            OOo 2.0.3
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration
from ..beans.x_hierarchical_property_set import XHierarchicalPropertySet as XHierarchicalPropertySet_679a10b9
from ..beans.x_multi_hierarchical_property_set import XMultiHierarchicalPropertySet as XMultiHierarchicalPropertySet_c18e12c4
from ..beans.x_multi_property_set import XMultiPropertySet as XMultiPropertySet_fd880e05
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class PropertyHierarchy(XHierarchicalPropertySet_679a10b9, XMultiHierarchicalPropertySet_c18e12c4, XMultiPropertySet_fd880e05, XPropertySet_bc180bfa):
    """
    Service Class

    provides access to and information about properties and subproperties of an implementation.
    
    Properties in a property set may be full-fledged objects that have properties themselves (and so on recursively), thereby forming a hierarchy of properties. This service describes such a hierarchy, and allows direct access even to subproperties.

    See Also:
        `API PropertyHierarchy <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1PropertyHierarchy.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.graphic
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from .x_graphic import XGraphic as XGraphic_a4da0afc

class XGraphicProvider(XInterface_8f010a43):
    """
    This interface acts as the main interface to handle graphic content.
    
    It is used to load graphics, store graphics and to get information about unloaded graphics

    See Also:
        `API XGraphicProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1graphic_1_1XGraphicProvider.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.graphic.XGraphicProvider']

    def queryGraphic(self, MediaProperties: 'PropertyValues_d6470ce6') -> 'XGraphic_a4da0afc':
        """
        Calling this method returns a XGraphic interface that holds the graphic content after loading the graphic.

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def queryGraphicDescriptor(self, MediaProperties: 'PropertyValues_d6470ce6') -> 'XPropertySet_bc180bfa':
        """
        Calling this method returns a com.sun.star.beans.XPropertySet interface that gives access to the properties of the unloaded graphic.
        
        In most cases, this method will be used to query the mime type of the graphic and, in the case of pixel graphics, the resulting size after loading

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def storeGraphic(self, Graphic: 'XGraphic_a4da0afc', MediaProperties: 'PropertyValues_d6470ce6') -> None:
        """
        Store the graphic content, represented through the XGraphic interface at the specified location.

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.logging
import typing
from .x_console_handler import XConsoleHandler as XConsoleHandler_fdad0dd8
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3

class ConsoleHandler(XConsoleHandler_fdad0dd8):
    """
    Service Class

    specifies a component implementing a log handler whose output channel is the processes console.
    
    **since**
    
        OOo 2.3

    See Also:
        `API ConsoleHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1logging_1_1ConsoleHandler.html>`_
    """
    def create(self) -> None:
        """
        creates a ConsoleHandler
        """
    def createWithSettings(self, Settings: 'typing.Tuple[NamedValue_a37a0af3, ...]') -> None:
        """
        creates an instance of the log handler, using generic settings
        
        The following settings are recognized and supported:

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal


class AccessibleEventId(object):
    """
    Const

    These constants identify the type of AccessibleEventObject objects.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain, where applicable and not otherwise stated, the old and new value of the property in question.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleEventId <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1accessibility_1_1AccessibleEventId.html>`_
    """
    NAME_CHANGED: Literal[1]
    """
    Use this event type to indicate a change of the name string of an accessible object.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the name before and after the change.
    """
    DESCRIPTION_CHANGED: Literal[2]
    """
    Use this event type to indicate a change of the description string of an accessible object.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the description before and after the change.
    """
    ACTION_CHANGED: Literal[3]
    """
    The change of the number or attributes of actions of an accessible object is signaled by events of this type.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the old and new number of actions.
    """
    STATE_CHANGED: Literal[4]
    """
    State changes are signaled with this event type.
    
    Use one event for every state that is set or reset. The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the old and new value respectively. To set a state put the state id into the AccessibleEventObject.NewValue field and leave AccessibleEventObject.OldValue empty. To reset a state put the state id into the AccessibleEventObject.OldValue field and leave AccessibleEventObject.NewValue empty.
    """
    ACTIVE_DESCENDANT_CHANGED: Literal[5]
    """
    Constant used to determine when the active descendant of a component has changed.
    
    The active descendant is used in objects with transient children. The AccessibleEventObject.NewValue contains the now active object. The AccessibleEventObject.OldValue contains the previously active child. Empty references indicate that no child has been respectively is currently active.
    """
    BOUNDRECT_CHANGED: Literal[6]
    """
    This event indicates a change of the bounding rectangle of an accessible object with respect only to its size or relative position.
    
    If the absolute position changes but not the relative position then it is not necessary to send an event.
    
    Use this event rather than the VISIBLE_DATA_EVENT when really only the (relative) bounding box of an accessible object has changed. It is much more specific than the later one and reduces the number of calls an AT-Tool has to make to retrieve all affected data.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue remain empty. Use a call to the XAccessibleComponent.getBounds() method to determine the new bounding box.
    """
    CHILD: Literal[7]
    """
    A child event indicates the addition of a new or the removal of an existing child.
    
    The contents of the AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields determines which of both has taken place.
    
    If a new child has been added then the AccessibleEventObject.NewValue contains a reference to this new object and AccessibleEventObject.OldValue remains empty.
    
    If a child has been removed then the AccessibleEventObject.OldValue contains a reference to this object and AccessibleEventObject.NewValue remains empty.
    
    If a child has been added and another one has been removed don't set both fields at the same. Send separate events instead.
    
    Note that a child event is sent after a child has been added or removed. Especially in the case of a removal this means that the removed object does not have a parent anymore.
    """
    INVALIDATE_ALL_CHILDREN: Literal[8]
    """
    Use this event to tell the listeners to re-retrieve the whole set of children.
    
    This should be used by a parent object which exchanges all or most of its children. It is a short form of first sending one CHILD event for every old child indicating that this child is about to be removed and then sending one CHILD for every new child indicating that this child has been added to the list of children.
    
    When this API is used by Java or Gnome AT-Tools then a bridge can generate the events described above automatically.
    """
    SELECTION_CHANGED: Literal[9]
    """
    Events of this type indicate changes of the selection.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields remain empty.
    """
    VISIBLE_DATA_CHANGED: Literal[10]
    """
    A visible data event indicates the change of the visual appearance of an accessible object.
    
    This includes for example most of the attributes available over the XAccessibleComponent and XAccessibleExtendedComponent interfaces. The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields are left empty.
    """
    VALUE_CHANGED: Literal[11]
    """
    This constant indicates changes of the value of an XAccessibleValue interface.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue field contain the old and new value as a number. Its exact type is implementation dependent but has to be the same as is returned by the XAccessibleValue.getCurrentValue() function.
    """
    CONTENT_FLOWS_FROM_RELATION_CHANGED: Literal[12]
    """
    Identifies the change of a relation set: The content flow has changed.
    
    Not used: The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain references to the old and new predecessor. Note that both references my be NULL to indicate that a flow to the sending object has not existed or does not exist anymore.
    """
    CONTENT_FLOWS_TO_RELATION_CHANGED: Literal[13]
    """
    Identifies the change of a relation set: The content flow has changed.
    
    Not used: The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain references to the old and new successor. Note that both references my be NULL to indicate that a flow from the sending object has not existed or does not exist anymore.
    """
    CONTROLLED_BY_RELATION_CHANGED: Literal[14]
    """
    Identifies the change of a relation set: The target object that is doing the controlling has changed.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the old and new controlling objects.
    """
    CONTROLLER_FOR_RELATION_CHANGED: Literal[15]
    """
    Identifies the change of a relation set: The controller for the target object has changed.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the old and new number of controlled objects.
    """
    LABEL_FOR_RELATION_CHANGED: Literal[16]
    """
    Identifies the change of a relation set: The target group for a label has changed.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the old and new number labeled objects.
    """
    LABELED_BY_RELATION_CHANGED: Literal[17]
    """
    Identifies the change of a relation set: The objects that are doing the labeling have changed.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the old and new accessible label.
    """
    MEMBER_OF_RELATION_CHANGED: Literal[18]
    """
    Identifies the change of a relation set: The group membership has changed.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the old and new number of members.
    """
    SUB_WINDOW_OF_RELATION_CHANGED: Literal[19]
    """
    Identifies the change of a relation set: The sub-window-of relation has changed.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the old and new accessible parent window objects.
    """
    CARET_CHANGED: Literal[20]
    """
    Events of this type are sent when the caret has moved to a new position.
    
    The old and new position can be found in the AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields.
    """
    TEXT_SELECTION_CHANGED: Literal[21]
    """
    Events of this type signal changes of the selection.
    
    The old or new selection is not available through the event object. You have to query the XAccessibleText interface of the event source for this information. The type of content of the AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields is not specified at the moment. This may change in the future.
    """
    TEXT_CHANGED: Literal[22]
    """
    Use this id to indicate general text changes, i.e.
    
    changes to text that is exposed through the XAccessibleText and XAccessibleEditableText interfaces.
    
    The affected text ranges are represented by com.sun.star.accessibility.TextSegment structures.
    
    The content of the AccessibleEventObject.OldValue and AccessibleEventObject.NewValue expresses the type of text change:
    
    When broadcasting an event always prefer the first three cases to the last one. Use it only as a last resort.
    
    Text ranges should be as small as possible but, of course, include all the text that is involved in a modification. That means that when two or more discontinuous text ranges are inserted, deleted, or otherwise modified the two fields of the event have to cover all the affected text ranges as well as the text in between.
    """
    TEXT_ATTRIBUTE_CHANGED: Literal[23]
    """
    This entry is reserved for future extension.
    
    Don't use it right now.
    """
    HYPERTEXT_CHANGED: Literal[24]
    """
    Constant used to indicate that a hypertext element has received focus.
    
    The AccessibleEventObject.OldValue field contains the start index of previously focused element. The AccessibleEventObject.NewValue field holds the start index in the document of the current element that has focus. A value of -1 indicates that an element does not or did not have focus.
    """
    TABLE_CAPTION_CHANGED: Literal[25]
    """
    Constant used to indicate that the table caption has changed.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the old and new accessible objects representing the table caption.
    """
    TABLE_COLUMN_DESCRIPTION_CHANGED: Literal[26]
    """
    Constant used to indicate that the column description has changed.
    
    The AccessibleEventObject.NewValue field contains the column index. The AccessibleEventObject.OldValue is left empty.
    """
    TABLE_COLUMN_HEADER_CHANGED: Literal[27]
    """
    Constant used to indicate that the column header has changed.
    
    The AccessibleEventObject.OldValue is empty, the AccessibleEventObject.NewValue field contains an AccessibleTableModelChange representing the header change.
    """
    TABLE_MODEL_CHANGED: Literal[28]
    """
    Constant used to indicate that the table data has changed.
    
    The AccessibleEventObject.OldValue is empty, the AccessibleEventObject.NewValue field contains an AccessibleTableModelChange representing the data change.
    """
    TABLE_ROW_DESCRIPTION_CHANGED: Literal[29]
    """
    Constant used to indicate that the row description has changed.
    
    The AccessibleEventObject.NewValue field contains the row index. The AccessibleEventObject.OldValue is left empty.
    """
    TABLE_ROW_HEADER_CHANGED: Literal[30]
    """
    Constant used to indicate that the row header has changed.
    
    The AccessibleEventObject.OldValue is empty, the AccessibleEventObject.NewValue field contains an AccessibleTableModelChange representing the header change.
    """
    TABLE_SUMMARY_CHANGED: Literal[31]
    """
    Constant used to indicate that the table summary has changed.
    
    The AccessibleEventObject.OldValue and AccessibleEventObject.NewValue fields contain the old and new accessible objects representing the table summary.
    """
    LISTBOX_ENTRY_EXPANDED: Literal[32]
    """
    Constant used to indicate that a list box entry has been expanded.
    
    AccessibleEventObject.OldValue is empty. AccessibleEventObject.NewValue contains the expanded list box entry.
    
    **since**
    
        OOo 3.2
    """
    LISTBOX_ENTRY_COLLAPSED: Literal[33]
    """
    Constant used to indicate that a list box entry has been collapsed.
    
    AccessibleEventObject.OldValue is empty. AccessibleEventObject.NewValue contains the collapsed list box entry.
    
    **since**
    
        OOo 3.2
    """
    ACTIVE_DESCENDANT_CHANGED_NOFOCUS: Literal[34]
    """
    Constant used to determine when the active descendant of a component has been removed but unlike ACTIVE_DESCENDANT_CHANGED the descendant that is to be removed does not have focus.
    
    The active descendant is used in objects with transient children.
    
    AccessibleEventObject.OldValue contains the item to be removed.
    
    AccessibleEventObject.NewValue is empty.
    
    **since**
    
        LibreOffice 4.3
    """
    SELECTION_CHANGED_ADD: Literal[35]
    """
    An item in a container has been added to an already present selection.
    
    Example: a second list item has been selected in a listbox.
    
    AccessibleEventObject.OldValue is empty.
    
    AccessibleEventObject.NewValue contains the item to be added.
    
    **since**
    
        LibreOffice 4.3
    """
    SELECTION_CHANGED_REMOVE: Literal[36]
    """
    An item in a container has been removed from the selection.
    
    AccessibleEventObject.OldValue contains the item to be removed.
    
    AccessibleEventObject.NewValue is empty.
    
    **since**
    
        LibreOffice 4.3
    """
    SELECTION_CHANGED_WITHIN: Literal[37]
    """
    Multiple items in a container object have been added or removed from the selection.
    
    AccessibleEventObject.OldValue and AccessibleEventObject.NewValue is empty.
    
    **since**
    
        LibreOffice 4.3
    """
    PAGE_CHANGED: Literal[38]
    """
    A change of page or slide.
    
    **since**
    
        LibreOffice 4.3
    """
    SECTION_CHANGED: Literal[39]
    """
    The cursor has moved to/from a section.
    
    **since**
    
        LibreOffice 4.3
    """
    COLUMN_CHANGED: Literal[40]
    """
    The cursor has moved to/from a section.
    
    **since**
    
        LibreOffice 4.3
    """
    ROLE_CHANGED: Literal[41]
    """
    Constant used to indicate that the role of an accessible object has changed.
    
    **since**
    
        LibreOffice 4.3
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .remote_content_provider_change_action import RemoteContentProviderChangeAction as RemoteContentProviderChangeAction_e9701378


class RemoteContentProviderChangeEvent(EventObject_a3d70b03):
    """
    Struct Class

    The description of a change to a com.sun.star.ucb.XRemoteContentProviderSupplier.

    See Also:
        `API RemoteContentProviderChangeEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1RemoteContentProviderChangeEvent.html>`_
    """
    typeName: Literal['com.sun.star.ucb.RemoteContentProviderChangeEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., Identifier: typing.Optional[str] = ..., Action: typing.Optional[RemoteContentProviderChangeAction_e9701378] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Identifier (str, optional): Identifier value.
            Action (RemoteContentProviderChangeAction, optional): Action value.
        """


    @property
    def Identifier(self) -> str:
        """
        The identifier with which the remote content provider is registered at the com.sun.star.ucb.XRemoteContentProviderSupplier.
        """


    @property
    def Action(self) -> RemoteContentProviderChangeAction_e9701378:
        """
        An indicator whether a remote content provider has been added or removed.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.embed
from typing_extensions import Literal
import typing
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..io.x_stream import XStream as XStream_678908a4

class XStorage(XNameAccess_e2ab0cf6, XComponent_98dc0ab5):
    """
    This interface represents main storage functionality.

    See Also:
        `API XStorage <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XStorage.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.embed.XStorage']

    def cloneEncryptedStreamElement(self, sStreamName: str, sPassword: str) -> 'XStream_678908a4':
        """
        allows to get readonly copy of a child encrypted stream with password.
        
        If storage does not allow any encryption this method will always throw com.sun.star.packages.NoEncryptionException.
        
        The stream is open in readonly mode so the com.sun.star.io.XStream.getOutputStream() method will return an empty reference.
        
        This method allows to specify reading password for the child stream explicitly.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.NoEncryptionException: ``NoEncryptionException``
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def cloneStreamElement(self, sStreamName: str) -> 'XStream_678908a4':
        """
        allows to get readonly copy of a child stream of the storage.
        
        The stream is open in readonly mode so the com.sun.star.io.XStream.getOutputStream() method will return an empty reference.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def copyElementTo(self, sElementName: str, xDest: 'XStorage', sNewName: str) -> None:
        """
        allows to copy an entry from one storage to another.
        
        If target element supports transacted mode it must be committed by this method after successful copying.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def copyLastCommitTo(self, xTargetStorage: 'XStorage') -> None:
        """
        allows to get copy of this storage at the state of its last commit.
        
        This method makes sense only for services implementations that allow transaction in the storage.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def copyStorageElementLastCommitTo(self, sStorName: str, xTargetStorage: 'XStorage') -> None:
        """
        allows to get copy of a child storage at the state of its last commit.
        
        This method makes sense only for services implementations that allow transaction in the storage.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def copyToStorage(self, xDest: 'XStorage') -> None:
        """
        allows to copy current storage to another one
        
        The destination storage contents are overwritten. After the successful copying the target storage is automatically committed if it implements transacted access.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def isStorageElement(self, sElementName: str) -> bool:
        """
        allows to check if an element is a child storage with specified name.
        
        In case there is no child element with such name an exception will be thrown.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
        """
    def isStreamElement(self, sElementName: str) -> bool:
        """
        allows to check if an element is a child stream with specified name.
        
        In case there is no child element with such name an exception will be thrown.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
        """
    def moveElementTo(self, sElementName: str, xDest: 'XStorage', sNewName: str) -> None:
        """
        allows to move an entry from one storage to another.
        
        If target element supports transacted mode it must be committed by this method after successful moving.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def openEncryptedStreamElement(self, sStreamName: str, nOpenMode: int, sPassword: str) -> 'XStream_678908a4':
        """
        allows to get access to a child encrypted stream with password.
        
        If storage does not allow any encryption this method will always throw com.sun.star.packages.NoEncryptionException.
        
        In case the stream is open in readonly mode the com.sun.star.io.XStream.getOutputStream() method will return an empty reference.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.NoEncryptionException: ``NoEncryptionException``
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def openStorageElement(self, sStorName: str, nOpenMode: int) -> 'XStorage':
        """
        allows to get access to a child storage.
        
        The opened substorage must support specified in \"nOpenMode\" access modes. It can support \"read\" mode in addition. But any child element can support one of those modes only in case this mode is supported by parent storage.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def openStreamElement(self, sStreamName: str, nOpenMode: int) -> 'XStream_678908a4':
        """
        allows to get access to a child stream of the storage.
        
        In case the stream is open in readonly mode the com.sun.star.io.XStream.getOutputStream() method will return an empty reference.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def removeElement(self, sElementName: str) -> None:
        """
        removes an element from a storage.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def renameElement(self, sElementName: str, sNewName: str) -> None:
        """
        renames an element in a storage.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rdf
from typing_extensions import Literal
import typing
from ..container.x_enumeration import XEnumeration as XEnumeration_f2180daa

class XQuerySelectResult(XEnumeration_f2180daa):
    """
    represents the result of a SPARQL \"SELECT\" query.
    
    The result consists of:
    
    Note that each query result retrieved via com.sun.star.container.XEnumeration.nextElement() has the type XNode[], the length of the sequence being the same as the number of query variables.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XQuerySelectResult <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rdf_1_1XQuerySelectResult.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rdf.XQuerySelectResult']

    def getBindingNames(self) -> 'typing.Tuple[str, ...]':
        """
        get the names of the query variables.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_dispatch_recorder import XDispatchRecorder as XDispatchRecorder_fbd70dd1
    from ..util.url import URL as URL_57ad07b9

class XRecordableDispatch(XInterface_8f010a43):
    """
    extends an existing XDispatch implementation with functionality for dispatch recording
    
    This interface can be implemented as an additional one beside an existing XDispatch one to provide record functionality of dispatches. Because it's an additional interface the status events are available there and not at this interface.
    
    But normally this interface mustn't be used directly. If a dispatch object is well known and recording was enabled on a XDispatchRecorderSupplier it's possible to use method XDispatchRecorderSupplier.dispatchAndRecord() of it to make dispatch and recording automatically. The interface XRecordableDispatch is used transparently there.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XRecordableDispatch <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XRecordableDispatch.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XRecordableDispatch']

    def dispatchAndRecord(self, URL: 'URL_57ad07b9', Arguments: 'typing.Tuple[PropertyValue_c9610c73, ...]', Recorder: 'XDispatchRecorder_fbd70dd1') -> None:
        """
        dispatch and record it
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa
    from .conversion_direction import ConversionDirection as ConversionDirection_7dfe113c

class XConversionDictionary(XInterface_8f010a43):
    """
    Allows the user to access a conversion dictionary.
    
    The dictionary consists of entries (pairs) of the form ( aLeftText, aRightText ). Those pairs can be added and removed. Also it can be looked for all entries where the left text or the right text matches a given text. Thus it can be used for conversions in both directions.
    
    Restrictions to what has to be the left and right text are usually given by specific services implementing this interface.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XConversionDictionary <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XConversionDictionary.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.linguistic2.XConversionDictionary']

    def addEntry(self, aLeftText: str, aRightText: str) -> None:
        """
        is used to add a conversion pair to the dictionary.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
    def clear(self) -> None:
        """
        removes all entries from the dictionary.
        """
    def getConversionEntries(self, eDirection: 'ConversionDirection_7dfe113c') -> 'typing.Tuple[str, ...]':
        """
        """
    def getConversionType(self) -> int:
        """
        """
    def getConversions(self, aText: str, nStartPos: int, nLength: int, eDirection: 'ConversionDirection_7dfe113c', nTextConversionOptions: int) -> 'typing.Tuple[str, ...]':
        """
        searches for entries or conversions that match the given text.
        
        The exact string to be looked for is the substring from the aText parameter that starts at position nStartPos and has the length nLength.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getLocale(self) -> 'Locale_70d308fa':
        """
        """
    def getMaxCharCount(self, eDirection: 'ConversionDirection_7dfe113c') -> int:
        """
        returns the maximum number of characters used as left or right text in entries.
        """
    def getName(self) -> str:
        """
        """
    def isActive(self) -> bool:
        """
        """
    def removeEntry(self, aLeftText: str, aRightText: str) -> None:
        """
        removes a conversion pair from the dictionary.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def setActive(self, bActivate: bool) -> None:
        """
        specifies whether the dictionary should be used or not .
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ui
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..lang.x_single_component_factory import XSingleComponentFactory as XSingleComponentFactory_46cc0fef

class UIElementSettings(XIndexAccess_f0910d6d, XSingleComponentFactory_46cc0fef):
    """
    Service Class

    describes the internal structure of a configurable user interface element.
    
    No assumption is made about any graphical representation: You could have a menu or a toolbar working with the same UIElementSettings although limitations based on the real user interface element may be visible.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UIElementSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1UIElementSettings.html>`_
    """
    @property
    def UIName(self) -> str:
        """
        determine an optional user interface name of the user interface element.
        
        A toolbar can show its user interface name on the window title, when it is in floating mode.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from typing_extensions import Literal


class CommandType(object):
    """
    Const

    indicates the type of a command.

    See Also:
        `API CommandType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1CommandType.html>`_
    """
    TABLE: Literal[0]
    """
    indicates that a command contains a table name, which can be used to process a command like \"select * from tablename\".
    """
    QUERY: Literal[1]
    """
    indicates that a command contains a name of a query component, which contains a certain statement.
    """
    COMMAND: Literal[2]
    """
    indicates that the command is an SQL-Statement.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script
# Libre Office Version: 7.2
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .interrupt_reason import InterruptReason as InterruptReason_f3d00dd2


class InterruptEngineEvent(EventObject_a3d70b03):
    """
    Struct Class

    describes an interrupt which occurs in the scripting engine.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API InterruptEngineEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1script_1_1InterruptEngineEvent.html>`_
    """
    typeName: Literal['com.sun.star.script.InterruptEngineEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., Name: typing.Optional[str] = ..., SourceCode: typing.Optional[str] = ..., StartLine: typing.Optional[int] = ..., StartColumn: typing.Optional[int] = ..., EndLine: typing.Optional[int] = ..., EndColumn: typing.Optional[int] = ..., ErrorMessage: typing.Optional[str] = ..., Reason: typing.Optional[InterruptReason_f3d00dd2] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Name (str, optional): Name value.
            SourceCode (str, optional): SourceCode value.
            StartLine (int, optional): StartLine value.
            StartColumn (int, optional): StartColumn value.
            EndLine (int, optional): EndLine value.
            EndColumn (int, optional): EndColumn value.
            ErrorMessage (str, optional): ErrorMessage value.
            Reason (InterruptReason, optional): Reason value.
        """


    @property
    def Name(self) -> str:
        """
        fully qualified name to address the module or function affected by the event that took place.
        
        If the module or function can't be addressed by name (for example, in case that a runtime-generated eval-module is executed), this string is empty.
        """


    @property
    def SourceCode(self) -> str:
        """
        source code of the Module affected by the event that took place.
        
        If the source can be accessed using the ModuleName, or if the source is unknown (executing compiled code), this string can be empty.
        """


    @property
    def StartLine(self) -> int:
        """
        contains the first line in the module's source code that is affected by the event that took place.
        
        If \"name\" addresses a function, all line and column values are nevertheless given relative to the module's source. If source code is not available, this value addresses a binary position in the compiled code.
        """


    @property
    def StartColumn(self) -> int:
        """
        contains the first column in the \"StartLine\" that is affected by the event that took place.
        """


    @property
    def EndLine(self) -> int:
        """
        contains the last line in the module's source code that is affected by the event that took place.
        """


    @property
    def EndColumn(self) -> int:
        """
        contains the first column in the \"EndLine\" which is NOT affected by the event that took place.
        """


    @property
    def ErrorMessage(self) -> str:
        """
        error message.
        
        Only valid if Reason is RuntimeError or CompileError.
        """


    @property
    def Reason(self) -> InterruptReason_f3d00dd2:
        """
        contains the interrupt reason.
        """


